(function(webapi, $){
    function safeAjax(ajaxOptions) {
        var deferredAjax = $.Deferred();

        shell.getTokenDeferred().done(function (token) {
            // add headers for ajax
            if (!ajaxOptions.headers) {
                $.extend(ajaxOptions, {
                    headers: {
                        "__RequestVerificationToken": token
                    }
                }); 
            } else {
                ajaxOptions.headers["__RequestVerificationToken"] = token;
            }
            $.ajax(ajaxOptions)
                .done(function(data, textStatus, jqXHR) {
                    validateLoginSession(data, textStatus, jqXHR, deferredAjax.resolve);
                }).fail(deferredAjax.reject); //ajax
        }).fail(function () {
            deferredAjax.rejectWith(this, arguments); // on token failure, pass the token ajax and args
        });

        return deferredAjax.promise();  
    }
    webapi.safeAjax = safeAjax;
})(window.webapi = window.webapi || {}, jQuery);

window.createProductRegistration = function(entityObj) {

    const actionUrl = `/_api/flk_productregistrations`;

    return new Promise(function(resolve, reject) {
        webapi.safeAjax({
            type: "POST",
            url: actionUrl,
            contentType: "application/json",
            data: JSON.stringify(entityObj),
            success: function (res, status, xhr) {
                resolve(xhr.getResponseHeader('entityid'));
            },
            error: function (e) {
                reject(e);
            }
        });
    });
};

window.setActivationCode = function (entityId, activationCode) {

    const actionUrl = `/_api/flk_productregistrations(${entityId})/flk_activation_code`;

    const paramsObj = { 
        'value': activationCode
    };

    return new Promise(function(resolve, reject) {
        webapi.safeAjax({
            type: "PUT",
            url: actionUrl,
            contentType: "application/json",
            data: JSON.stringify(paramsObj),
            success: function (res) {
                resolve(res);
            },
            error: function (e) {
                reject(e);
            }
        });
    });
};